# This file was auto-generated by Fern from our API Definition.

from ...core.pydantic_utilities import UniversalBaseModel
import typing_extensions
import typing
from ...core.serialization import FieldMetadata
import pydantic
from ...core.pydantic_utilities import IS_PYDANTIC_V2


class AnnotationsCreateBulkRequestSelectedItems(UniversalBaseModel):
    all_: typing_extensions.Annotated[typing.Optional[bool], FieldMetadata(alias="all")] = pydantic.Field(default=None)
    """
    Indicates whether to apply the operation to all tasks. If true, this overrides any included or excluded lists.
    """

    included: typing.Optional[typing.List[int]] = pydantic.Field(default=None)
    """
    An explicit list of task IDs to include.
    """

    excluded: typing.Optional[typing.List[int]] = pydantic.Field(default=None)
    """
    An explicit list of task IDs to exclude.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
