# This file was auto-generated by Fern from our API Definition.

import typing

BaseTaskUpdatedBy = typing.Union[
    typing.Optional[int], typing.Optional[typing.List[typing.Dict[str, typing.Optional[typing.Any]]]]
]
