# This file was auto-generated by Fern from our API Definition.

from .types import AnnotationsCreateBulkRequestSelectedItems, AnnotationsCreateBulkResponseItem

__all__ = ["AnnotationsCreateBulkRequestSelectedItems", "AnnotationsCreateBulkResponseItem"]
