# This file was auto-generated by Fern from our API Definition.

from ..core.pydantic_utilities import UniversalBaseModel
import typing
import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2


class TaskFilterOptions(UniversalBaseModel):
    view: typing.Optional[int] = pydantic.Field(default=None)
    """
    Apply filters from the view ID (a tab from the Data Manager)
    """

    skipped: typing.Optional[str] = pydantic.Field(default=None)
    """
    `only` - include all tasks with skipped annotations<br>`exclude` - exclude all tasks with skipped annotations
    """

    finished: typing.Optional[str] = pydantic.Field(default=None)
    """
    `only` - include all finished tasks (is_labeled = true)<br>`exclude` - exclude all finished tasks
    """

    annotated: typing.Optional[str] = pydantic.Field(default=None)
    """
    `only` - include all tasks with at least one not skipped annotation<br>`exclude` - exclude all tasks with at least one not skipped annotation
    """

    only_with_annotations: typing.Optional[bool] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
