# This file was auto-generated by Fern from our API Definition.

from ..core.pydantic_utilities import UniversalBaseModel
import typing
from .serialization_option import SerializationOption
import pydantic
import typing_extensions
from ..core.serialization import FieldMetadata
from ..core.pydantic_utilities import IS_PYDANTIC_V2


class SerializationOptions(UniversalBaseModel):
    drafts: typing.Optional[SerializationOption] = None
    predictions: typing.Optional[SerializationOption] = None
    include_annotation_history: typing.Optional[bool] = pydantic.Field(default=None)
    """
    Include annotation history
    """

    annotations_completed_by: typing_extensions.Annotated[
        typing.Optional[SerializationOption], FieldMetadata(alias="annotations__completed_by")
    ] = None
    interpolate_key_frames: typing.Optional[bool] = pydantic.Field(default=None)
    """
    Interpolate video key frames
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
