# This file was auto-generated by Fern from our API Definition.

from ....core.pydantic_utilities import UniversalBaseModel
import typing
import pydantic
from ....core.pydantic_utilities import IS_PYDANTIC_V2


class RedisUpdateResponse(UniversalBaseModel):
    db: typing.Optional[int] = pydantic.Field(default=None)
    """
    Database ID of database to use
    """

    can_delete_objects: typing.Optional[bool] = pydantic.Field(default=None)
    """
    Deletion from storage enabled.
    """

    title: typing.Optional[str] = pydantic.Field(default=None)
    """
    Storage title
    """

    description: typing.Optional[str] = pydantic.Field(default=None)
    """
    Storage description
    """

    project: typing.Optional[int] = pydantic.Field(default=None)
    """
    Project ID
    """

    path: typing.Optional[str] = pydantic.Field(default=None)
    """
    Storage prefix (optional)
    """

    host: typing.Optional[str] = pydantic.Field(default=None)
    """
    Server Host IP (optional)
    """

    port: typing.Optional[str] = pydantic.Field(default=None)
    """
    Server Port (optional)
    """

    password: typing.Optional[str] = pydantic.Field(default=None)
    """
    Server Password (optional)
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
