# This file was auto-generated by Fern from our API Definition.

from ..core.pydantic_utilities import UniversalBaseModel
from .comment_created_by import CommentCreatedBy
import datetime as dt
import typing
from ..core.pydantic_utilities import IS_PYDANTIC_V2
import pydantic


class Comment(UniversalBaseModel):
    id: int
    text: str
    project: int
    task: int
    annotation: int
    created_by: CommentCreatedBy
    created_at: dt.datetime
    updated_at: dt.datetime
    is_resolved: typing.Optional[bool] = None
    resolved_at: typing.Optional[dt.datetime] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
