# This file was auto-generated by Fern from our API Definition.

from .annotations_create_bulk_request_selected_items import AnnotationsCreateBulkRequestSelectedItems
from .annotations_create_bulk_response_item import AnnotationsCreateBulkResponseItem

__all__ = ["AnnotationsCreateBulkRequestSelectedItems", "AnnotationsCreateBulkResponseItem"]
