# This file was auto-generated by Fern from our API Definition.

from ..core.pydantic_utilities import UniversalBaseModel
import typing
from .prompt_version_provider import PromptVersionProvider
from .prompt_version_created_by import PromptVersionCreatedBy
import datetime as dt
from .prompt_version_organization import PromptVersionOrganization
from ..core.pydantic_utilities import IS_PYDANTIC_V2
import pydantic


class PromptVersion(UniversalBaseModel):
    title: typing.Optional[str] = None
    parent_model: typing.Optional[int] = None
    model_provider_connection: typing.Optional[int] = None
    prompt: typing.Optional[str] = None
    provider: typing.Optional[PromptVersionProvider] = None
    provider_model_id: typing.Optional[str] = None
    created_by: typing.Optional[PromptVersionCreatedBy] = None
    created_at: typing.Optional[dt.datetime] = None
    updated_at: typing.Optional[dt.datetime] = None
    organization: typing.Optional[PromptVersionOrganization] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
